pub fn get_runfilename(
run: u32,
subrun: u64,
rb_id: Option<u8>,
timestamp: Option<String>,
tof_only: bool,
) -> StringExpand description
A standardized name for regular run files saved by the liftof suite
Arguments
- run : run id (identifier)
- subrun : subrun id (identifier of file # within the run
- rb_id : in case this should be used on the rb, a rb id can be specified as well
- timestamp : substitute the current time with this timestamp (or basically any other string) instead.
- tof_only : if true, the filename will end with the suffix .tof.gaps, if false it will end simply with .gaps